@@ -18,7 +18,7 @@ use Test::BrewBuild::BrewCommands;
 use Test::BrewBuild::Dispatch;
 use Test::BrewBuild::Tester;
 
-our $VERSION = '2.06';
+our $VERSION = '2.07';
 
 my $log;
 my $bcmd;
@@ -85,7 +85,7 @@ sub config_file {
     shift;
     if (is_win()){
         return $ENV{BB_CONF} if $ENV{BB_CONF};
-        return "$ENV{HOMEPATH}/brewbuild/brewbuild.conf";
+        return "$ENV{USERPROFILE}/brewbuild/brewbuild.conf";
     }
     else {
         return $ENV{BB_CONF} if $ENV{BB_CONF};
@@ -379,7 +379,7 @@ sub tempdir {
 sub workdir {
     my $self = shift;
     return is_win()
-        ? "$ENV{HOMEPATH}/brewbuild"
+        ? "$ENV{USERPROFILE}/brewbuild"
         : "$ENV{HOME}/brewbuild";
 }
 sub log {
@@ -1083,7 +1083,7 @@ perldoc command:
 
 Berrybrew for Windows:
 
-L<https://github.com/dnmfarrell/berrybrew>
+L<https://github.com/stevieb9/berrybrew>
 
 Perlbrew for Unixes:
 
@@ -1138,7 +1138,7 @@ Create a repository directory, and enter it:
     cd c:\repos
 
 Clone and configure berrybrew
-    git clone https://github.com/dnmfarrell/berrybrew
+    git clone https://github.com/stevieb9/berrybrew
     cd berrybrew
     bin\berrybrew.exe config (type 'y' when asked to install in PATH)
 
